@@ -25,9 +25,12 @@ def hexd(algo, value):
 def hashtag(algo, lib=False):
     def inner(value):
         return hexd(algo, value)
-    return filter(function(inner),doc='Returns %s hexadecimal hash of the value. %s' % (algo.upper(), lib and 'Requires the :mod:`hashlib` module' or ''),name=algo)
+    return filter(function(inner),
+        doc='Returns %s hexadecimal hash of the value. %s' % \
+            (algo.upper(), lib and 'Requires the :mod:`hashlib` module' or ''),
+        name=algo, test={'args':('wtf',),'result':hexd(algo, 'wtf')})
     
-md5 = hashtag( 'md5')
+md5 = hashtag('md5')
 sha1 = hashtag('sha1')
 sha224 = hashtag('sha224',True)
 sha256 = hashtag('sha256',True)
